stm32-metapac

Crates

git

Versions

stm32h573ri

Flavors

Ccvalr

Struct Ccvalr 

#[repr(transparent)]
pub struct Ccvalr(pub u32);
SBS compensation cell for I/Os value register

Tuple Fields

0: u32

Implementations



impl Ccvalr

pub const fn ansrc1(&self) -> u8

compensation value for the NMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.

pub const fn set_ansrc1(&mut self, val: u8)

compensation value for the NMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.

pub const fn apsrc1(&self) -> u8

compensation value for the PMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.

pub const fn set_apsrc1(&mut self, val: u8)

compensation value for the PMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.

pub const fn ansrc2(&self) -> u8

Compensation value for the NMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.

pub const fn set_ansrc2(&mut self, val: u8)

Compensation value for the NMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.

pub const fn apsrc2(&self) -> u8

compensation value for the PMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.

pub const fn set_apsrc2(&mut self, val: u8)

compensation value for the PMOS transistor This value is provided by the cell and must be interpreted by the processor to compensate the slew rate in the functional range.